@@ -1,9 +1,7 @@
 package Plack::Middleware::RequestId;
 use strict;
 use warnings;
-use 5.010000;
 
-use Data::UUID;
 use parent 'Plack::Middleware';
 use Plack::Util;
 use Plack::Util::Accessor qw/
@@ -12,9 +10,10 @@ use Plack::Util::Accessor qw/
     req_http_header
     id_generator
     force_generate_id
+    env_key
 /;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $request_id;
 
@@ -34,9 +33,11 @@ sub prepare_app {
     $self->req_http_header($req_http_header);
 
     unless ($self->id_generator) {
+        require Data::UUID;
+        Data::UUID->import;
+        $self->{_uuid_obj} = Data::UUID->new;
         $self->id_generator(sub {
-            state $ug = Data::UUID->new;
-            substr $ug->create_hex, 2, 32;
+            substr $self->{_uuid_obj}->create_hex, 2, 32;
         });
     }
 }
@@ -50,6 +51,10 @@ sub call {
             ? $env->{$self->req_http_header}
             : $self->id_generator->($env);
 
+    if ($self->env_key) {
+        $ENV{$self->env_key} = $request_id;
+    }
+
     my $res = $self->app->($env);
 
     $self->response_cb($res, sub {
@@ -116,6 +121,10 @@ The code ref for generating an ID. By default, using L<Data::UUID>.
 
 If you set true value to this oprion, then the ID always generates every request no matter what there is C<X-Request-Id> header.
 
+=head2 env_key
+
+If you would like to store request id in %ENV also, set a key strings to this option.
+
 
 =head1 Getting ID TIPS
 
@@ -137,7 +146,7 @@ Normally, you get the request ID from PSGI env. However, the ID has been stored
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1463920279"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1463920279&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-RequestId"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-RequestId.png?_t=1464415439"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-RequestId"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-RequestId/badge.png?_t=1464415439&branch=master"/></a>
 
 =end html
 
